@@ -5,7 +5,8 @@
              paste(sQuote("UComp"), "version:", ver),
              paste(sQuote("UComp"),
                    "is a package for time series modelling"),
-             "using Unobserved Components models",
+             "using Unobserved Components, Exponential ",
+             "smoothing and other sorts of models",
              "\n",
              "Author: Diego J. Pedregal",
              "Diego.Pedregal@uclm.es",
